from setuptools import setup

setup(name='pyQuickSortArray',
      version='1.05',
      description='Sorts an number array multiple ways',
      packages=['pyQuickSortArray'],
      author_email='vovaefanov478@gmail.com',
      zip_safe=False)